@@ -613,14 +613,14 @@ def apply_synonyms(file_keys,synonyms):
 def auto_tag_by_folder_name(watch_path,**kwargs):
     print(f"auto_tag_by_folder_name")
     synonyms = obj.get_kwarg(['synonyms'],False,(bool,dict),**kwargs)
-    all_files = f.get_files(watch_path, ext="images",data_include="img_meta_data")
+    all_files = f.get_files(watch_path, ext="images",include_meta_data=True)
     print(f"watching {len(all_files)} files")
     # duration = 0
 
     while True:
         time.sleep(.5)
         if len(all_files) == 0:
-            all_files = f.get_files(watch_path, ext="images",data_include="img_meta_data")
+            all_files = f.get_files(watch_path, ext="images",include_meta_data=True)
         # duration += .5
         # if duration % 10 == 0:
         #     transferCompleteImages.transferCompleteImages()
